@@ -21,6 +21,10 @@ if __name__ == '__main__':
     parser.set_defaults(copy_cmd=True)
     args = parser.parse_args()
 
+    if len(sys.argv) == 1:
+        parser.print_help()
+        exit(0)
+
     if args.copy_cmd :
         data = ""
         for line in sys.stdin:
